This data is associated with the paper "Surrogate-guided Optimization in Quantum Networks", available on arXiv [arxivlink].
In this work we introduce an efficient optimization workflow using machine-learning models that outperforms traditional techniques, addressing the challenges of complex, computationally demanding simulations in quantum networking.

We investigate three canonical quantum-networking setups:
1. Quantum Entanglement Switch: Tuning an experimental parameter, called the bright-state population, of a quantum entanglement switch in the single-click scheme to maximize utility based on distillable entanglement (folder quantum_entanglement_switch/).
2. Metropolitan Network: Allocation of quantum memories from a given budget to nine user nodes of a metropolitan quantum network in order to maximize the number of requests the network stack can serve (folder metropolitan_network/).
3. Continuous Protocols: We investigate the performance of continuous protocols (as opposed to on-demand protocols used in the first two use cases) on random-tree graphs with up to 100 nodes (folder continuous_distribution_protocols/).

How to produce tables and plots
-------------------------------
The associated git repository https://github.com/Luisenden/qnetsur provides plotting scripts `plotting.py` for each use case to regenerate tables and plots reported in the paper.
Clone the git repository, install Python (3.7+) and execute the following from the respective usecase folder

---
**Note:** 
the associated plots to folders starting with "notebook_.." are generated within Jupyter notebooks available in git
* notebook_cd_n3/ and notebook_cd_n20/ use in tutorial_pareto-analysis.ipynb 
* notebook_qswitch_vardoyan use in tutorial_vardoyan_netsquid_comparison.ipynb
---


```python
pip install -r requirements_plotting.txt
python plotting.py --folder 'path/to/QNETSUR-DATA/last/folder'
``` 

How data was generated
----------------------
Naming convention: Method_usecase_limit_SEED#_timestamp.csv, for exmple "AX_qswitch_0.5hours_SEED1_06-24-2024_10:00:40.csv"
where SU=Surrogate, AX=Meta, SA=Simulated Annealing, RS=Random Search.

In the examples studied, we conducted ten independent repetitions of for each optimization method in every use case, adhering to a specified number of iterations or a time limit, T. Note, that one simulation execution involves 20 runs by default. All optimization methods were executed allocating ten cores each on an Intel(R) Xeon(R) CPU E5-2620 v2 @ 2.10GHz and 64 GB of memory. Note, that in the scenarios involving a time limit for comparison between reference methods, the outcomes are specific to our computing system. For instance, let us assume a simulation takes nine seconds to execute on our system but ten seconds on a another computer. If we impose a time limit that permits ten optimization cycles on our system, the same time limit would only allow nine cycles on the slower system, resulting in different outcomes. Since execution times depend on multiple aspects of a computing node (processor speed, RAM, operating system), to ensure exact reproducibility of output data, it is advisable to use a fixed number of iterations; we diverged from this to enable fair comparison between all used optimization methods. 

We list the associated package requirements and execution commands per use case below

1. Quantum Entanglement Switch (quantum_entanglement_switch/)
In order to run the qswitch simulation in [NetSquid](https://netsquid.org) `netsquid==0.10.3` and the [qswitch snippet](https://github.com/Luisenden/netsquid-qswitch), `version 1.1.1` are required, using Python 3.7. In the cloned git repository https://github.com/Luisenden/qnetsur navigate to `usecase_qswitch` and execute what follows from this directory.
    **notebook_qswitch_vardoyan**
    Execute `python surrogate_vardoyan_netsquid_comparison.py --serverdist <distance> --iterator 100` (~3-10h runtime per distance) for distances [1, 12, 23, 34, 45, 56, 67, 78, 89, 100].
    **qswitch_30min**
    Using the parameter settings listed in SIMULATION_INPUT_VALUES.csv we executed for seeds 1-10 (30min runtime in total)

    ```python
    python surrogate.py --nleaf 6 --time 0.5 --seed 1 #generating all "SU_*.csv" files
    python vs_meta.py --nleaf 6 --time 0.5 --seed 1 #generating all "AX_*.csv" files
    python vs_simulatedannealing.py --nleaf 6 --time 0.5 --seed 1 #generating all "SA_*.csv" files
    python vs_randomsearch.py --nleaf 6 --time 0.5 --seed 1 #(generating all "RS_*.csv" files.
    ``` 

    Then, after successfull execution the best found soltuion of the above is retrieved and the simulation is run with the latter solution using
    `python run_sim_large.py --method Surrogate`, `python run_sim_large.py --method Meta`, `python run_sim_large.py --method 'Random Search`, `python run_sim_large.py --method 'Simulated Annealing'`

2. Metropolitan Network (metropolitan_network/)
In order to run the network simulation, the python module [SeQUeNCe](https://github.com/sequence-toolbox/SeQUeNCe), where we used a Python 3.9 environment.
Installation e.g., with `pip install git+https://github.com/sequence-toolbox/SeQUeNCe.git`. This time we executed what follows from `usecase_metropolitan`.

    **rb_25h**
    Similar to above, we use the parameter settings listed in SIMULATION_INPUT_VALUES.csv and executed for seeds 1-10 for all methods.
    ```python
    python surrogate.py --time 25 --seed 1 #generating the "SU_*.csv" file 
    ...
    ```

    After retrieving the best found solutions (Best_found_solutions.csv), we again simulated for n=1000 runs
    `python run_sim_large.py --method Surrogate`, `python run_sim_large.py --method Meta`, `python run_sim_large.py --method 'Random Search`, `python run_sim_large.py --method 'Simulated Annealing'`.
    We further run the simulation with the policies used in the associated [sequence paper](https://iopscience.iop.org/article/10.1088/2058-9565/ac22f6/pdf)
    `python run_sim_large.py --method Even`, `python run_sim_large.py --method 'Wu et. al, 2021'`.

3. Continuous Protocols (continuous_distribution_protocols)
We simulated continuous protocols using [OptimizingCD](https://github.com/AlvaroGI/optimizing-cd-protocols) whithin a Python 3.9 environment. Installation via `git+https://github.com/AlvaroGI/optimizing-cd-protocols.git@package`.

    **cd_1-10h**
    The simulation experiments are conducted in the same manner as above, using the associated scripts in the git directory `usecase_cd`.
    ```python
    python surrogate.py --topo randtree-100 --seed 1 --time i #where i=1,5 and 10 (hours) for seeds 1-10 and all four reference methods
    ...
    python run_sim_large.py --method Surrogate #and accordingly for the three reference methods
    ...
    ```
    to simualte the overall best found solution using n=1000 runs.

    **notebook_cd_n3** and **notebook_cd_n20**
    To generate the presented outcomes, we optimize the swap paramters per node using continuous protocols with `python surrogate.py --topo tree-2-1 --seed 42 --iterator 100` and `python surrogate.py --topo randtree-20 --seed 42 --iterator 100` using the parameter settings listed in SIMULATION_INPUT_VALUES.csv.




